Монгол spoj
===========

www.spoj.com/ABRAMOV/ (Sphere online judge) -д зориулсан CL хэрэгсэл.

Боломжууд:
- системд нэвтрэх
- шинээр бүртгүүлэх
- хэрэглэгчийн мэдээлэл
- бодлого илгээх
- бодлогууд
- бодлогын дэлгэрэнгүй
- шилдэг бодолтууд
- миний бодолтууд


Хэрхэн суулгах
--------------
???


Системд нэвтрэх
---------------
`login` коммандаар системд нэвтрэн орно.
Жишээ:
	
	>spoj.py login <username>
	>password: <password>


Шинээр бүртгүүлэх
-----------------
`register` коммандаар шинэ хэрэглэгч бүртгүүлнэ.


Хэрэглэгчийн мэдээлэл
---------------------
`status <user_name>` коммандаар тухайн хэрэглэгчийн мэдээллийг харна. Хэдэн
бодлого бүрэн бодсон болон хэдэн бодлого дутуу бодсон талаар мэдээлнэ. Хэрвээ
`<user_name>` тодорхойлогдоогүй байвал системд нэвтэрсэн хэрэглэгчийн
мэдээллийг харуулна.


Бодлого илгээх
--------------

`tackle` коммандаар бодлогоо илгээнэ, үүний тулд тухайн тухайн бодлогын 
дугаар болон кодын файлын нэрээ аргументэд нь өгнө. Кодын файлын 
өргөтгөл нь тухайн бодлогыг ямар хэл дээр шийдсэнийг илэрхийлнэ. 
Жишээ нь:

	>spoj.py tackle <problem_id> solution.c


Бодлогууд
---------
`problems'
